import unittest
import doctest

def test_suite():
    suite = unittest.TestSuite()
    suite.addTest(
        doctest.DocFileSuite(
            "README.txt",
            globs={'__name__':'dolmen.field.tests'},
            optionflags=(doctest.ELLIPSIS + doctest.NORMALIZE_WHITESPACE),
            )
        )
    return suite



# -*- coding: utf-8 -*-

from zope.schema import Field
from zope.schema import interfaces as errors
from zope.interface import implements
from zope.interface.verify import verifyClass
from zope.interface.interfaces import IInterface
from dolmen.field import IClassField


class GlobalClass(Field):
    """A field storing a class implementing a given schema.
    """
    implements(IClassField)

    def __init__(self, schema, **kw):
        if not IInterface.providedBy(schema):
            raise errors.WrongType(u"%r is not a valid Interface" % schema)

        self.schema = schema
        super(GlobalClass, self).__init__(**kw)

    def _validate(self, value):
        super(GlobalClass, self)._validate(value)

        # schema has to be provided by value
        if not self.schema.implementedBy(value):
            raise errors.ConstraintNotSatisfied(
                u"%r does not implement %r" % (value, self.schema))

        # check the value against schema
        verifyClass(self.schema, value)



# -*- coding: utf-8 -*-

from zope.interface import Interface
from zope.schema import InterfaceField
from zope.schema.interfaces import IField


class IClassField(IField):
    """Field requiring a valid class with an interface to validate.
    """
    schema = InterfaceField(
        required = False,
        title = u"Validation interface",
        description = u"Mandatory interface, needed to validate the value.",
        default = Interface
        )



from os.path import join
from setuptools import setup, find_packages

readme = open(join('src', 'dolmen', 'field', 'README.txt')).read()
history = open(join('docs', 'HISTORY.txt')).read()
name = 'dolmen.field'
version = '0.3'

setup(name = name,
      version = version,
      description = 'Generic Formlib fields',
      long_description = readme + '\n\n' + history,
      keywords = 'Grok Zope3 Dolmen',
      author = 'Souheil Chelfouh',
      author_email = 'trollfot@gmail.com',
      url = 'http://gitweb.dolmen-project.org',
      download_url = 'http://pypi.python.org/pypi/dolmen.field',
      license = 'GPL',
      packages=find_packages('src', exclude=['ez_setup']),
      package_dir={'': 'src'},
      namespace_packages = ['dolmen'],
      include_package_data = True,
      platforms = 'Any',
      zip_safe = False,
      install_requires=[
          'setuptools',
          'zope.schema',
          'zope.interface'
      ],
      classifiers = [
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Intended Audience :: Other Audience',
        'License :: OSI Approved :: GNU General Public License (GPL)',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
      ],
)
